@@ -129,8 +129,6 @@ pub struct StatsigOptionsPy {
     #[pyo3(get, set)]
     pub wait_for_country_lookup_init: Option<bool>,
     #[pyo3(get, set)]
-    pub disable_user_agent_parsing: Option<bool>,
-    #[pyo3(get, set)]
     pub disable_country_lookup: Option<bool>,
     #[pyo3(get, set)]
     pub id_lists_url: Option<String>,
@@ -158,6 +156,8 @@ pub struct StatsigOptionsPy {
     pub proxy_config: Option<Py<ProxyConfigPy>>,
     #[pyo3(get, set)]
     pub spec_adapter_configs: Option<Py<PyList>>,
+    #[pyo3(get, set)]
+    pub use_third_party_ua_parser: Option<bool>,
 }
 
 #[gen_stub_pymethods]
@@ -177,7 +177,6 @@ impl StatsigOptionsPy {
         enable_id_lists=None,
         wait_for_user_agent_init=None,
         wait_for_country_lookup_init=None,
-        disable_user_agent_parsing=None,
         disable_country_lookup=None,
         id_lists_url=None,
         id_lists_sync_interval_ms=None,
@@ -192,6 +191,7 @@ impl StatsigOptionsPy {
         proxy_config=None,
         output_logger_provider=None,
         spec_adapter_configs=None,
+        use_third_party_ua_parser=None,
     ))]
     #[allow(clippy::too_many_arguments)]
     pub fn new(
@@ -207,7 +207,6 @@ impl StatsigOptionsPy {
         enable_id_lists: Option<bool>,
         wait_for_user_agent_init: Option<bool>,
         wait_for_country_lookup_init: Option<bool>,
-        disable_user_agent_parsing: Option<bool>,
         disable_country_lookup: Option<bool>,
         id_lists_url: Option<String>,
         id_lists_sync_interval_ms: Option<u32>,
@@ -222,6 +221,7 @@ impl StatsigOptionsPy {
         proxy_config: Option<Py<ProxyConfigPy>>,
         output_logger_provider: Option<Py<OutputLoggerProviderBasePy>>,
         spec_adapter_configs: Option<Py<PyList>>,
+        use_third_party_ua_parser: Option<bool>,
     ) -> Self {
         Self {
             specs_url,
@@ -236,7 +236,6 @@ impl StatsigOptionsPy {
             wait_for_user_agent_init,
             wait_for_country_lookup_init,
             disable_country_lookup,
-            disable_user_agent_parsing,
             id_lists_url,
             id_lists_sync_interval_ms,
             fallback_to_statsig_api,
@@ -251,6 +250,7 @@ impl StatsigOptionsPy {
             proxy_config,
             output_logger_provider,
             spec_adapter_configs,
+            use_third_party_ua_parser,
         }
     }
 }
@@ -329,7 +329,6 @@ fn create_inner_statsig_options(
         global_custom_fields,
         disable_network: opts.disable_network,
         disable_country_lookup: opts.disable_country_lookup,
-        disable_user_agent_parsing: opts.disable_user_agent_parsing,
         persistent_storage: opts.persistent_storage.as_ref().map(|s| {
             Arc::new(StatsigPersistentStorageOverrideAdapter::new(
                 s.extract(py).unwrap_or_default(),
@@ -366,7 +365,7 @@ fn create_inner_statsig_options(
                     .unwrap_or_default(),
             ) as Arc<dyn OutputLogProvider>
         }),
-        __experimental_ua_parsing_enabled: None,
+        use_third_party_ua_parser: opts.use_third_party_ua_parser,
     }
 }
 
