@@ -68,14 +68,14 @@ fn test_memoization_from_map() {
 }
 
 fn get_memo_len() -> usize {
-    let memo = dynamic_returnable::MEMOIZED_VALUES.try_lock().unwrap();
+    let memo = dynamic_returnable::INTERNED_STORE
+        .values
+        .try_lock()
+        .unwrap();
 
     for (key, value) in memo.iter() {
         let value = value.upgrade().unwrap();
-        println!(
-            "{}: RawValue({:?}), Bool({:?}), Json({:?})",
-            key, value.raw_value, value.bool_value, value.json_value
-        );
+        println!("{}: RawValue({:?})", key, value.raw_value);
     }
 
     memo.len()
