@@ -1,15 +1,13 @@
 use super::dynamic_returnable::DynamicReturnable;
+use crate::evaluation::evaluation_types::is_false;
 use crate::interned_string::InternedString;
 use crate::SecondaryExposure;
-use crate::{
-    evaluation::evaluation_types::is_false, event_logging::exposable_string::ExposableString,
-};
 use serde::{Deserialize, Serialize};
 
 #[derive(Serialize, Deserialize, Clone)]
 pub struct BaseEvaluationV2 {
     pub name: String,
-    pub rule_id: ExposableString,
+    pub rule_id: InternedString,
     pub secondary_exposures: Vec<String>,
 }
 
@@ -18,7 +16,8 @@ pub struct GateEvaluationV2 {
     #[serde(flatten)]
     pub base: BaseEvaluationV2,
 
-    pub id_type: InternedString,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub id_type: Option<InternedString>,
     pub value: bool,
 }
 
@@ -27,11 +26,10 @@ pub struct DynamicConfigEvaluationV2 {
     #[serde(flatten)]
     pub base: BaseEvaluationV2,
 
-    pub id_type: InternedString,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub id_type: Option<InternedString>,
     pub value: DynamicReturnable,
 
-    // The 'group' field is identical to 'rule_id'. See group_name instead.
-    pub group: ExposableString,
     pub is_device_based: bool,
 
     pub passed: bool,
@@ -42,11 +40,10 @@ pub struct ExperimentEvaluationV2 {
     #[serde(flatten)]
     pub base: BaseEvaluationV2,
 
-    pub id_type: InternedString,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub id_type: Option<InternedString>,
     pub value: DynamicReturnable,
 
-    // The 'group' field is identical to 'rule_id'. See group_name instead.
-    pub group: ExposableString,
     pub is_device_based: bool,
 
     #[serde(skip_serializing_if = "is_false")]
@@ -81,10 +78,9 @@ pub struct LayerEvaluationV2 {
 
     pub value: DynamicReturnable,
 
-    pub id_type: InternedString,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub id_type: Option<InternedString>,
 
-    // The 'group' field is identical to 'rule_id'. See group_name instead.
-    pub group: ExposableString,
     pub is_device_based: bool,
 
     #[serde(skip_serializing_if = "Option::is_none")]
