@@ -10,24 +10,25 @@ use crate::evaluation::dynamic_value::DynamicValue;
 use crate::evaluation::evaluation_details::EvaluationDetails;
 use crate::evaluation::evaluation_types::SecondaryExposure;
 use crate::evaluation::evaluator_context::EvaluatorContext;
-use crate::evaluation::evaluator_value::{EvaluatorValue, EvaluatorValueType};
+use crate::evaluation::evaluator_value::{EvaluatorValue, MemoizedEvaluatorValue};
 use crate::evaluation::get_unit_id::get_unit_id;
 use crate::evaluation::user_agent_parsing::UserAgentParser;
-use crate::event_logging::exposable_string;
+use crate::interned_string::InternedString;
 use crate::specs_response::spec_types::{Condition, Rule, Spec};
-use crate::{dyn_value, log_e, unwrap_or_return, StatsigErr};
+use crate::{dyn_value, log_w, unwrap_or_return, StatsigErr};
 
 use super::country_lookup::CountryLookup;
 
-const TAG: &str = stringify!(Evaluator);
+const TAG: &str = "Evaluator";
 
 pub struct Evaluator;
 
 lazy_static! {
     static ref EMPTY_STR: String = String::new();
-    static ref EMPTY_EVALUATOR_VALUE: EvaluatorValue =
-        EvaluatorValue::new(EvaluatorValueType::Null);
     static ref EMPTY_DYNAMIC_VALUE: DynamicValue = DynamicValue::new();
+    static ref DEFAULT_RULE: InternedString = InternedString::from_str_ref("default");
+    static ref DISABLED_RULE: InternedString = InternedString::from_str_ref("disabled");
+    static ref SALT: InternedString = InternedString::from_str_ref("salt");
 }
 
 #[derive(Clone)]
@@ -38,7 +39,7 @@ pub enum SpecType {
     Layer,
 }
 
-#[derive(PartialEq, Eq)]
+#[derive(PartialEq, Eq, Debug)]
 pub enum Recognition {
     Unrecognized,
     Recognized,
@@ -104,7 +105,7 @@ impl Evaluator {
         }
 
         if ctx.result.id_type.is_none() {
-            ctx.result.id_type = Some(&spec.id_type);
+            ctx.result.id_type = Some(InternedString::from_str_ref(&spec.id_type));
         }
 
         if ctx.result.version.is_none() {
@@ -152,7 +153,7 @@ impl Evaluator {
             }
 
             ctx.result.rule_id = Some(&rule.id);
-            ctx.result.group_name = rule.group_name.as_ref();
+            ctx.result.group_name = rule.group_name.clone();
             ctx.result.is_experiment_group = rule.is_experiment_group.unwrap_or(false);
             ctx.result.is_experiment_active = spec.is_active.unwrap_or(false);
             ctx.finalize_evaluation(spec, Some(rule));
@@ -162,8 +163,8 @@ impl Evaluator {
         ctx.result.bool_value = spec.default_value.get_bool() == Some(true);
         ctx.result.json_value = Some(spec.default_value.clone());
         ctx.result.rule_id = match spec.enabled {
-            true => Some(&exposable_string::DEFAULT_RULE),
-            false => Some(&exposable_string::DISABLED_RULE),
+            true => Some(&DEFAULT_RULE),
+            false => Some(&DISABLED_RULE),
         };
         ctx.finalize_evaluation(spec, None);
 
@@ -194,7 +195,7 @@ fn try_apply_config_mapping(
 
     let spec_salt = match opt_spec {
         Some(spec) => &spec.salt,
-        None => &EMPTY_STR,
+        None => InternedString::empty_ref(),
     };
 
     for mapping in mapping_list {
@@ -278,7 +279,7 @@ fn evaluate_rule<'a>(ctx: &mut EvaluatorContext<'a>, rule: &'a Rule) -> Result<(
         let condition = if let Some(c) = opt_condition {
             c
         } else {
-            // todo: log condition not found error
+            log_w!(TAG, "Unsupported - Condition not found: {}", condition_hash);
             ctx.result.unsupported = true;
             return Ok(());
         };
@@ -303,10 +304,11 @@ fn evaluate_condition<'a>(
     let target_value = condition
         .target_value
         .as_ref()
-        .unwrap_or(&EMPTY_EVALUATOR_VALUE);
-    let condition_type = &condition.condition_type;
+        .map(|v| v.inner.as_ref())
+        .unwrap_or(EvaluatorValue::empty().inner.as_ref());
+    let condition_type = condition.condition_type.as_str();
 
-    let value: &DynamicValue = match condition_type as &str {
+    let value: &DynamicValue = match condition_type {
         "public" => {
             ctx.result.bool_value = true;
             return Ok(());
@@ -322,7 +324,7 @@ fn evaluate_condition<'a>(
                     ctx.user,
                     &condition.field,
                     &mut ctx.result.override_reason,
-                    ctx.use_experimental_ua_parser,
+                    ctx.should_user_third_party_parser,
                 );
                 temp_value.as_ref()
             }
@@ -352,6 +354,11 @@ fn evaluate_condition<'a>(
         "target_app" => ctx.app_id,
         "unit_id" => ctx.user.get_unit_id(&condition.id_type),
         _ => {
+            log_w!(
+                TAG,
+                "Unsupported - Unknown condition type: {}",
+                condition_type
+            );
             ctx.result.unsupported = true;
             return Ok(());
         }
@@ -361,14 +368,15 @@ fn evaluate_condition<'a>(
     // println!("Eval Condition {}, {:?}", condition_type, value);
 
     let operator = match &condition.operator {
-        Some(operator) => operator,
+        Some(operator) => operator.as_str(),
         None => {
+            log_w!(TAG, "Unsupported - Operator is None",);
             ctx.result.unsupported = true;
             return Ok(());
         }
     };
 
-    ctx.result.bool_value = match operator as &str {
+    ctx.result.bool_value = match operator {
         // numerical comparisons
         "gt" | "gte" | "lt" | "lte" => compare_numbers(value, target_value, operator),
 
@@ -406,6 +414,7 @@ fn evaluate_condition<'a>(
         | "not_array_contains_all" => compare_arrays(value, target_value, operator),
 
         _ => {
+            log_w!(TAG, "Unsupported - Unknown operator: {}", operator);
             ctx.result.unsupported = true;
             return Ok(());
         }
@@ -417,13 +426,13 @@ fn evaluate_condition<'a>(
 fn evaluate_id_list(
     ctx: &mut EvaluatorContext<'_>,
     op: &str,
-    target_value: &EvaluatorValue,
+    target_value: &MemoizedEvaluatorValue,
     value: &DynamicValue,
 ) -> bool {
     let list_name = unwrap_or_return!(&target_value.string_value, false);
     let id_lists = &ctx.spec_store_data.id_lists;
 
-    let list = unwrap_or_return!(id_lists.get(&list_name.value), false);
+    let list = unwrap_or_return!(id_lists.get(list_name.value.as_str()), false);
 
     let dyn_str = unwrap_or_return!(&value.string_value, false);
     let hashed = ctx.hashing.sha256(&dyn_str.value);
@@ -440,21 +449,14 @@ fn evaluate_id_list(
 
 fn evaluate_nested_gate<'a>(
     ctx: &mut EvaluatorContext<'a>,
-    target_value: &'a EvaluatorValue,
-    condition_type: &'a String,
+    target_value: &'a MemoizedEvaluatorValue,
+    condition_type: &'a str,
 ) -> Result<(), StatsigErr> {
-    let gate_name = if let Some(name) = target_value.string_value.as_ref() {
-        &name.value
-    } else {
-        log_e!(
-            TAG,
-            "Invalid target_value for condition {}, {:?}",
-            condition_type,
-            target_value
-        );
-        ctx.result.unsupported = true;
-        return Ok(());
-    };
+    let gate_name = target_value
+        .string_value
+        .as_ref()
+        .map(|name| &name.value)
+        .unwrap_or(InternedString::empty_ref());
 
     match ctx.nested_gate_memo.get(gate_name.as_str()) {
         Some((previous_bool, previous_rule_id)) => {
@@ -463,14 +465,19 @@ fn evaluate_nested_gate<'a>(
         }
         None => {
             ctx.prep_for_nested_evaluation()?;
-            let _ = Evaluator::evaluate(ctx, gate_name, &SpecType::Gate)?;
+
+            let _ = Evaluator::evaluate(ctx, gate_name.as_str(), &SpecType::Gate)?;
 
             if ctx.result.unsupported {
                 return Ok(());
             }
 
-            ctx.nested_gate_memo
-                .insert(gate_name, (ctx.result.bool_value, ctx.result.rule_id));
+            if !gate_name.as_str().is_empty() {
+                ctx.nested_gate_memo.insert(
+                    gate_name.as_str(),
+                    (ctx.result.bool_value, ctx.result.rule_id),
+                );
+            }
         }
     }
 
@@ -478,11 +485,8 @@ fn evaluate_nested_gate<'a>(
         let res = &ctx.result;
         let expo = SecondaryExposure {
             gate: gate_name.clone(),
-            gate_value: res.bool_value.to_string(),
-            rule_id: res
-                .rule_id
-                .unwrap_or(&exposable_string::EMPTY_STRING)
-                .clone(),
+            gate_value: InternedString::from_bool(res.bool_value),
+            rule_id: res.rule_id.unwrap_or(InternedString::empty_ref()).clone(),
         };
 
         if res.sampling_rate.is_none() {
@@ -518,12 +522,16 @@ fn evaluate_config_delegate<'a>(
     }
 
     ctx.result.explicit_parameters = delegate_spec.spec.explicit_parameters.as_ref();
-    ctx.result.config_delegate = rule.config_delegate.as_ref();
+    ctx.result.config_delegate = rule.config_delegate.clone();
 
     Ok(true)
 }
 
-fn evaluate_pass_percentage(ctx: &mut EvaluatorContext, rule: &Rule, spec_salt: &String) -> bool {
+fn evaluate_pass_percentage(
+    ctx: &mut EvaluatorContext,
+    rule: &Rule,
+    spec_salt: &InternedString,
+) -> bool {
     if rule.pass_percentage == 100f64 {
         return true;
     }
@@ -544,10 +552,10 @@ fn evaluate_pass_percentage(ctx: &mut EvaluatorContext, rule: &Rule, spec_salt:
 fn get_hash_for_user_bucket(ctx: &mut EvaluatorContext, condition: &Condition) -> DynamicValue {
     let unit_id = get_unit_id(ctx, &condition.id_type);
 
-    let mut salt: &String = &EMPTY_STR;
+    let mut salt = InternedString::empty_ref();
 
     if let Some(add_values) = &condition.additional_values {
-        if let Some(v) = add_values.get("salt") {
+        if let Some(v) = add_values.get(&SALT) {
             salt = v;
         }
     }
