@@ -1,14 +1,15 @@
+use std::collections::HashMap;
+use std::sync::Arc;
+
 use crate::evaluation::dynamic_value::DynamicValue;
 use crate::evaluation::evaluator_result::EvaluatorResult;
-use crate::event_logging::exposable_string::ExposableString;
 use crate::hashing::HashUtil;
+use crate::interned_string::InternedString;
 use crate::spec_store::SpecStoreData;
 use crate::specs_response::spec_types::{Rule, Spec};
 use crate::user::StatsigUserInternal;
 use crate::StatsigErr::StackOverflowError;
 use crate::{OverrideAdapter, StatsigErr};
-use std::collections::HashMap;
-use std::sync::Arc;
 
 const MAX_RECURSIVE_DEPTH: u16 = 300;
 
@@ -20,8 +21,8 @@ pub struct EvaluatorContext<'a> {
     pub nested_count: u16,
     pub app_id: Option<&'a DynamicValue>,
     pub override_adapter: Option<&'a Arc<dyn OverrideAdapter>>,
-    pub nested_gate_memo: HashMap<&'a str, (bool, Option<&'a ExposableString>)>,
-    pub use_experimental_ua_parser: bool,
+    pub nested_gate_memo: HashMap<&'a str, (bool, Option<&'a InternedString>)>,
+    pub should_user_third_party_parser: bool,
 }
 
 impl<'a> EvaluatorContext<'a> {
@@ -31,7 +32,7 @@ impl<'a> EvaluatorContext<'a> {
         hashing: &'a HashUtil,
         app_id: Option<&'a DynamicValue>,
         override_adapter: Option<&'a Arc<dyn OverrideAdapter>>,
-        use_experimental_ua_parser: bool,
+        should_user_third_party_parser: bool,
     ) -> Self {
         let result = EvaluatorResult::default();
 
@@ -44,7 +45,7 @@ impl<'a> EvaluatorContext<'a> {
             override_adapter,
             nested_count: 0,
             nested_gate_memo: HashMap::new(),
-            use_experimental_ua_parser,
+            should_user_third_party_parser,
         }
     }
 
