@@ -8,13 +8,12 @@ use crate::evaluation::evaluation_types::{
     BaseEvaluation, DynamicConfigEvaluation, ExperimentEvaluation, GateEvaluation, LayerEvaluation,
     SecondaryExposure,
 };
-use crate::event_logging::exposable_string::{self, ExposableString};
 use crate::hashing::{HashAlgorithm, HashUtil};
 use crate::interned_string::InternedString;
 
 #[derive(Default, Debug)]
 pub struct EvaluatorResult<'a> {
-    pub name: Option<&'a ExposableString>,
+    pub name: Option<&'a InternedString>,
     pub bool_value: bool,
     pub unsupported: bool,
     pub is_experiment_group: bool,
@@ -23,7 +22,7 @@ pub struct EvaluatorResult<'a> {
     pub is_in_experiment: bool,
     pub id_type: Option<InternedString>,
     pub json_value: Option<DynamicReturnable>,
-    pub rule_id: Option<&'a ExposableString>,
+    pub rule_id: Option<&'a InternedString>,
     pub rule_id_suffix: Option<&'static str>,
     pub group_name: Option<InternedString>,
     pub explicit_parameters: Option<&'a Vec<InternedString>>,
@@ -41,7 +40,7 @@ pub struct EvaluatorResult<'a> {
 pub fn result_to_gate_eval(gate_name: &str, result: &mut EvaluatorResult) -> GateEvaluation {
     GateEvaluation {
         base: result_to_base_eval(gate_name, result),
-        id_type: result.id_type.take().unwrap_or_default(),
+        id_type: result.id_type.take(),
         value: result.bool_value,
     }
 }
@@ -53,7 +52,7 @@ pub fn result_to_gate_eval_v2(
 ) -> GateEvaluationV2 {
     GateEvaluationV2 {
         base: result_to_base_eval_v2(gate_name, result, hashing),
-        id_type: result.id_type.take().unwrap_or_default(),
+        id_type: result.id_type.take(),
         value: result.bool_value,
     }
 }
@@ -75,8 +74,7 @@ pub fn result_to_experiment_eval(
 
     ExperimentEvaluation {
         base: result_to_base_eval(experiment_name, result),
-        id_type,
-        group: result.rule_id.cloned().unwrap_or_default(),
+        id_type: Some(id_type),
         is_device_based,
         value: get_json_value(result),
         is_in_layer: result.is_in_layer,
@@ -110,8 +108,7 @@ pub fn result_to_experiment_eval_v2(
 
     ExperimentEvaluationV2 {
         base: result_to_base_eval_v2(experiment_name, result, hashing),
-        id_type,
-        group: result.rule_id.cloned().unwrap_or_default(),
+        id_type: Some(id_type),
         is_device_based,
         value: get_json_value(result),
         is_in_layer: result.is_in_layer,
@@ -131,8 +128,7 @@ pub fn eval_result_to_experiment_eval(
 
     ExperimentEvaluation {
         base: result_to_base_eval(experiment_name, result),
-        id_type,
-        group: result.rule_id.cloned().unwrap_or_default(),
+        id_type: Some(id_type),
         is_device_based,
         value: get_json_value(result),
         is_in_layer: result.is_in_layer,
@@ -164,10 +160,6 @@ pub fn result_to_layer_eval(layer_name: &str, result: &mut EvaluatorResult) -> L
 
     LayerEvaluation {
         base: result_to_base_eval(layer_name, result),
-        group: result
-            .rule_id
-            .map(|r| InternedString::from_str_ref(r.as_str()))
-            .unwrap_or_default(),
         value: get_json_value(result),
         is_device_based,
         group_name: result.group_name.take(),
@@ -176,7 +168,7 @@ pub fn result_to_layer_eval(layer_name: &str, result: &mut EvaluatorResult) -> L
         allocated_experiment_name,
         explicit_parameters: result.explicit_parameters.cloned().unwrap_or_default(),
         undelegated_secondary_exposures: Some(undelegated_sec_expos.unwrap_or_default()),
-        id_type,
+        id_type: Some(id_type),
     }
 }
 
@@ -216,7 +208,6 @@ pub fn result_to_layer_eval_v2(
 
     LayerEvaluationV2 {
         base: result_to_base_eval_v2(layer_name, result, hashing),
-        group: result.rule_id.cloned().unwrap_or_default(),
         value: get_json_value(result),
         is_device_based,
         group_name: result.group_name.take(),
@@ -225,7 +216,7 @@ pub fn result_to_layer_eval_v2(
         allocated_experiment_name,
         explicit_parameters: result.explicit_parameters.cloned().unwrap_or_default(),
         undelegated_secondary_exposures: Some(undelegated_secondary_exposures),
-        id_type,
+        id_type: Some(id_type),
     }
 }
 
@@ -237,10 +228,9 @@ pub fn result_to_dynamic_config_eval(
 
     DynamicConfigEvaluation {
         base: result_to_base_eval(dynamic_config_name, result),
-        id_type,
+        id_type: Some(id_type),
         is_device_based,
         value: get_json_value(result),
-        group: result.rule_id.cloned().unwrap_or_default(),
         passed: result.bool_value,
     }
 }
@@ -254,10 +244,9 @@ pub fn result_to_dynamic_config_eval_v2(
 
     DynamicConfigEvaluationV2 {
         base: result_to_base_eval_v2(dynamic_config_name, result, hashing),
-        id_type,
+        id_type: Some(id_type),
         is_device_based,
         value: get_json_value(result),
-        group: result.rule_id.cloned().unwrap_or_default(),
         passed: result.bool_value,
     }
 }
@@ -278,13 +267,13 @@ fn get_json_value(result: &mut EvaluatorResult) -> DynamicReturnable {
 // todo: remove when 'QueuedExposure' does not use `BaseEvaluation`
 fn get_exposure_name_if_not_hashed(
     possibly_hashed_name: &str,
-    exposure_name: Option<&ExposableString>,
-) -> ExposableString {
-    let exposure_name = exposure_name.unwrap_or(&exposable_string::EMPTY_STRING);
+    exposure_name: Option<&InternedString>,
+) -> InternedString {
+    let exposure_name = exposure_name.unwrap_or(InternedString::empty_ref());
     if possibly_hashed_name == exposure_name.as_str() {
         exposure_name.clone()
     } else {
-        ExposableString::from_str_ref(possibly_hashed_name)
+        InternedString::from_str_ref(possibly_hashed_name)
     }
 }
 
@@ -337,16 +326,16 @@ fn result_to_base_eval_v2(
 }
 
 fn create_suffixed_rule_id(
-    rule_id: Option<&ExposableString>,
+    rule_id: Option<&InternedString>,
     suffix: Option<&str>,
-) -> ExposableString {
+) -> InternedString {
     let id_arc = match &rule_id {
         Some(rule_id) => rule_id.as_str(),
         None => "",
     };
 
     match &suffix {
-        Some(suffix) => ExposableString::from_str_parts(&[id_arc, ":", suffix]),
+        Some(suffix) => InternedString::from_str_parts(&[id_arc, ":", suffix]),
         None => rule_id.cloned().unwrap_or_default(),
     }
 }
