@@ -35,6 +35,10 @@ impl UaParser {
                 return create_res(token.tag, token.get_version());
             }
 
+            if token.tag.starts_with("Android") {
+                return create_res("Android", None);
+            }
+
             if token.tag == "Chromecast" {
                 return create_res("Chromecast", None);
             }
@@ -129,6 +133,13 @@ impl UaParser {
                 return create_res("Edge", token.get_version());
             }
 
+            if token.tag == "Opera" {
+                if result.mobile_hint {
+                    return create_res("Opera Mobile", token.get_version());
+                }
+                return create_res("Opera", token.get_version());
+            }
+
             if token.tag == "Chrome" {
                 chrome_token = Some(token);
                 continue;
@@ -165,9 +176,12 @@ impl UaParser {
             return create_res("Android", token.get_version());
         }
 
-        if result.cfnetwork_hint {
+        if result.cfnetwork_hint && !result.tokens.is_empty() {
             if result.tokens[0].tag == "NetworkingExtension" {
-                return create_res("CFNetwork", result.tokens[1].get_version());
+                return create_res(
+                    "CFNetwork",
+                    result.tokens.get(1).and_then(|t| t.get_version()),
+                );
             }
             return create_res(result.tokens[0].tag, result.tokens[0].get_version());
         }
@@ -175,7 +189,8 @@ impl UaParser {
         if result.safari_hint {
             let version = version_token.and_then(|t| t.get_version());
 
-            if result.mobile_hint {
+            if result.mobile_hint && !result.macos_hint {
+                // UA string has this “Mobile” flag likely for compatibility or simulation purposes but it's running ins macos
                 return create_res("Mobile Safari", version);
             }
 
@@ -183,7 +198,10 @@ impl UaParser {
         }
 
         if result.ios_hint {
-            return create_res("Mobile Safari UI/WKWebView", None);
+            return create_res(
+                "Mobile Safari UI/WKWebView",
+                result.possible_os_token.and_then(|o| o.get_version()),
+            );
         }
 
         if result.crawler_hint {
