@@ -1,6 +1,6 @@
 use super::IdListMetadata;
 use crate::id_lists_adapter::{IdListUpdate, IdListsAdapter, IdListsUpdateListener};
-use crate::networking::{NetworkClient, NetworkError, RequestArgs, Response};
+use crate::networking::{NetworkClient, NetworkError, RequestArgs, Response, ResponseData};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
 use crate::sdk_diagnostics::diagnostics::ContextType;
@@ -17,8 +17,9 @@ use std::time::Duration;
 use tokio::sync::Notify;
 use tokio::time::sleep;
 
+const STATSIG_CDN_URL: &str = "https://api.statsigcdn.com";
 const DEFAULT_CDN_ID_LISTS_MANIFEST_URL: &str = "https://api.statsigcdn.com/v1/get_id_lists";
-const DEFAULT_ID_LIST_SYNC_INTERVAL_MS: u32 = 10_000;
+const DEFAULT_ID_LIST_SYNC_INTERVAL_MS: u32 = 60_000;
 
 type IdListsResponse = HashMap<String, IdListMetadata>;
 
@@ -121,18 +122,24 @@ impl StatsigHttpIdListsAdapter {
         list_size: u64,
     ) -> Result<String, StatsigErr> {
         let headers = HashMap::from([("Range".into(), format!("bytes={list_size}-"))]);
+        let query_params = if list_url.starts_with(STATSIG_CDN_URL) {
+            Some(HashMap::from([("range".into(), format!("{list_size}-"))]))
+        } else {
+            None
+        };
 
         let response = self
             .network
             .get(RequestArgs {
                 url: list_url.to_string(),
                 headers: Some(headers),
+                query_params,
                 ..RequestArgs::new()
             })
             .await
             .map_err(StatsigErr::NetworkError)?;
 
-        let response_body = match response.data.filter(|data| !data.is_empty()) {
+        let mut response_body = match response.data {
             Some(data) => data,
             None => {
                 let msg = "No ID List changes from network".to_string();
@@ -140,7 +147,7 @@ impl StatsigHttpIdListsAdapter {
             }
         };
 
-        String::from_utf8(response_body).map_err(|err| {
+        response_body.read_to_string().map_err(|err| {
             let msg = format!("Failed to parse ID List changes: {err:?}");
             StatsigErr::JsonParseError("IdList".to_string(), msg)
         })
@@ -161,6 +168,7 @@ impl StatsigHttpIdListsAdapter {
             Err(e) => Err(StatsigErr::NetworkError(e)),
         }
     }
+
     async fn run_background_sync(weak_self: &Weak<Self>) {
         let strong_self = match weak_self.upgrade() {
             Some(s) => s,
@@ -186,8 +194,11 @@ impl StatsigHttpIdListsAdapter {
             .starts_with(DEFAULT_CDN_ID_LISTS_MANIFEST_URL)
     }
 
-    fn parse_response(&self, response: Option<Vec<u8>>) -> Result<IdListsResponse, StatsigErr> {
-        let response = match response.filter(|r| !r.is_empty()) {
+    fn parse_response(
+        &self,
+        response: Option<ResponseData>,
+    ) -> Result<IdListsResponse, StatsigErr> {
+        let mut data = match response {
             Some(r) => r,
             None => {
                 let msg = "No ID List results from network".to_string();
@@ -198,10 +209,11 @@ impl StatsigHttpIdListsAdapter {
             }
         };
 
-        serde_json::from_slice::<IdListsResponse>(&response).map_err(|parse_err| {
-            let msg = format!("Failed to parse JSON: {parse_err}");
-            StatsigErr::JsonParseError(stringify!(IdListsResponse).to_string(), msg)
-        })
+        data.deserialize_into::<IdListsResponse>()
+            .map_err(|parse_err| {
+                let msg = format!("Failed to parse JSON: {parse_err}");
+                StatsigErr::JsonParseError(stringify!(IdListsResponse).to_string(), msg)
+            })
     }
 
     fn set_listener(&self, listener: Arc<dyn IdListsUpdateListener>) {
