@@ -1,11 +1,13 @@
+use crate::networking::ResponseData;
 use crate::specs_adapter::{SpecsAdapter, SpecsSource, SpecsUpdate, SpecsUpdateListener};
 use crate::statsig_err::StatsigErr;
 use crate::{log_e, StatsigRuntime};
 use async_trait::async_trait;
 use chrono::Utc;
-
-use std::sync::{Arc, RwLock};
+use parking_lot::RwLock;
+use std::sync::Arc;
 use std::time::Duration;
+
 pub struct StatsigBootstrapSpecsAdapter {
     data: RwLock<String>,
     listener: RwLock<Option<Arc<dyn SpecsUpdateListener>>>,
@@ -22,31 +24,44 @@ impl StatsigBootstrapSpecsAdapter {
     }
 
     pub fn set_data(&self, data: String) -> Result<(), StatsigErr> {
-        match self.data.write() {
-            Ok(mut lock) => *lock = data.clone(),
-            Err(e) => return Err(StatsigErr::LockFailure(e.to_string())),
+        match self.data.try_write_for(std::time::Duration::from_secs(5)) {
+            Some(mut lock) => *lock = data.clone(),
+            None => {
+                return Err(StatsigErr::LockFailure(
+                    "Failed to acquire write lock on data".to_string(),
+                ))
+            }
         };
 
         self.push_update()
     }
 
     fn push_update(&self) -> Result<(), StatsigErr> {
-        let data = match self.data.read() {
-            Ok(lock) => lock.clone(),
-            Err(e) => return Err(StatsigErr::LockFailure(e.to_string())),
+        let data = match self.data.try_read_for(std::time::Duration::from_secs(5)) {
+            Some(lock) => lock.clone(),
+            None => {
+                return Err(StatsigErr::LockFailure(
+                    "Failed to acquire read lock on data".to_string(),
+                ))
+            }
         };
 
-        match &self.listener.read() {
-            Ok(lock) => match lock.as_ref() {
+        match &self
+            .listener
+            .try_read_for(std::time::Duration::from_secs(5))
+        {
+            Some(lock) => match lock.as_ref() {
                 Some(listener) => listener.did_receive_specs_update(SpecsUpdate {
-                    data: data.into_bytes(),
+                    data: ResponseData::from_bytes(data.into_bytes()),
                     source: SpecsSource::Bootstrap,
                     received_at: Utc::now().timestamp_millis() as u64,
                     source_api: None,
                 }),
                 None => Err(StatsigErr::UnstartedAdapter("Listener not set".to_string())),
             },
-            Err(e) => Err(StatsigErr::LockFailure(e.to_string())),
+            None => Err(StatsigErr::LockFailure(
+                "Failed to acquire read lock on listener".to_string(),
+            )),
         }
     }
 }
@@ -61,10 +76,13 @@ impl SpecsAdapter for StatsigBootstrapSpecsAdapter {
     }
 
     fn initialize(&self, listener: Arc<dyn SpecsUpdateListener>) {
-        match self.listener.write() {
-            Ok(mut lock) => *lock = Some(listener),
-            Err(e) => {
-                log_e!(TAG, "Failed to acquire write lock on listener: {}", e);
+        match self
+            .listener
+            .try_write_for(std::time::Duration::from_secs(5))
+        {
+            Some(mut lock) => *lock = Some(listener),
+            None => {
+                log_e!(TAG, "Failed to acquire write lock on listener");
             }
         }
     }
@@ -111,7 +129,7 @@ mod tests {
     #[async_trait]
     impl SpecsUpdateListener for TestListener {
         fn did_receive_specs_update(&self, update: SpecsUpdate) -> Result<(), StatsigErr> {
-            if let Ok(mut lock) = self.received_update.write() {
+            if let Some(mut lock) = self.received_update.try_write() {
                 *lock = Some(update);
             }
             Ok(())
@@ -138,11 +156,14 @@ mod tests {
         adapter.initialize(listener.clone());
         adapter.clone().start(&statsig_rt).await.unwrap();
 
-        if let Ok(lock) = listener.clone().received_update.read() {
-            let update = lock.as_ref().unwrap();
-            assert_eq!(update.source, SpecsSource::Bootstrap);
-            assert_eq!(update.data, test_data.into_bytes());
-        }
+        let mut update = listener
+            .received_update
+            .try_write()
+            .unwrap()
+            .take()
+            .unwrap();
+        assert_eq!(update.source, SpecsSource::Bootstrap);
+        assert_eq!(update.data.read_to_string().unwrap(), test_data);
     }
 
     #[tokio::test]
@@ -159,10 +180,13 @@ mod tests {
         let result = adapter.set_data(test_data.clone());
         assert!(result.is_ok());
 
-        if let Ok(lock) = listener.clone().received_update.read() {
-            let update = lock.as_ref().unwrap();
-            assert_eq!(update.source, SpecsSource::Bootstrap);
-            assert_eq!(update.data, test_data.into_bytes());
-        }
+        let mut update = listener
+            .received_update
+            .try_write()
+            .unwrap()
+            .take()
+            .unwrap();
+        assert_eq!(update.source, SpecsSource::Bootstrap);
+        assert_eq!(update.data.read_to_string().unwrap(), test_data);
     }
 }
