@@ -4,7 +4,7 @@ use crate::evaluation::evaluation_types::{
     DynamicConfigEvaluation, ExperimentEvaluation, GateEvaluation, LayerEvaluation,
 };
 use crate::event_logging::event_logger::EventLogger;
-use crate::event_logging::exposable_string::{self, ExposableString};
+use crate::interned_string::InternedString;
 use crate::statsig_types::{DynamicConfig, Experiment, FeatureGate, Layer};
 use crate::user::StatsigUserLoggable;
 use std::sync::Weak;
@@ -18,9 +18,16 @@ pub fn make_feature_gate(
         Some(e) => (
             e.value,
             e.base.rule_id.clone(),
-            e.id_type.unperformant_to_string(),
+            match e.id_type {
+                Some(ref id_type) => id_type.unperformant_to_string(),
+                None => "".into(),
+            },
+        ),
+        None => (
+            false,
+            InternedString::from_str_ref("default"),
+            String::new(),
         ),
-        None => (false, exposable_string::DEFAULT_RULE.clone(), String::new()),
     };
 
     FeatureGate {
@@ -37,7 +44,7 @@ pub fn extract_from_experiment_evaluation(
     evaluation: &Option<ExperimentEvaluation>,
 ) -> (
     DynamicReturnable,
-    ExposableString,
+    InternedString,
     String,
     Option<String>,
     bool,
@@ -46,13 +53,16 @@ pub fn extract_from_experiment_evaluation(
         Some(e) => (
             e.value.clone(),
             e.base.rule_id.clone(),
-            e.id_type.unperformant_to_string(),
+            match e.id_type {
+                Some(ref id_type) => id_type.unperformant_to_string(),
+                None => "".into(),
+            },
             e.group_name.as_ref().map(|g| g.unperformant_to_string()),
             e.is_experiment_active.unwrap_or(false),
         ),
         None => (
             DynamicReturnable::empty(),
-            exposable_string::DEFAULT_RULE.clone(),
+            InternedString::from_str_ref("default"),
             String::new(),
             None,
             false,
@@ -69,11 +79,14 @@ pub fn make_dynamic_config(
         Some(e) => (
             e.value.clone(),
             e.base.rule_id.clone(),
-            e.id_type.unperformant_to_string(),
+            match e.id_type {
+                Some(ref id_type) => id_type.unperformant_to_string(),
+                None => "".into(),
+            },
         ),
         None => (
             DynamicReturnable::empty(),
-            exposable_string::DEFAULT_RULE.clone(),
+            InternedString::from_str_ref("default"),
             String::new(),
         ),
     };
@@ -126,12 +139,15 @@ pub fn make_layer(
                 e.allocated_experiment_name
                     .as_ref()
                     .map(|g| g.unperformant_to_string()),
-                e.id_type.unperformant_to_string(),
+                match e.id_type {
+                    Some(ref id_type) => id_type.unperformant_to_string(),
+                    None => "".into(),
+                },
                 e.is_experiment_active.unwrap_or(false),
             ),
             None => (
                 DynamicReturnable::empty(),
-                exposable_string::DEFAULT_RULE.clone(),
+                InternedString::from_str_ref("default"),
                 None,
                 None,
                 "".into(),
