@@ -25,6 +25,11 @@ pub mod specs_adapter_tests {
             adapter_type: SpecsAdapterType::NetworkGrpcWebsocket,
             specs_url: Some(format!("http://{}", mock_proxy.proxy_address)),
             init_timeout_ms: 3000,
+            authentication_mode: None,
+            ca_cert_path: None,
+            client_cert_path: None,
+            client_key_path: None,
+            domain_name: None,
         };
         let adapter = Arc::new(StatsigGrpcSpecsAdapter::new("secret-key", &config, None));
         let mock_listener = Arc::new(MockSpecsListener::default());
@@ -87,10 +92,10 @@ pub mod specs_adapter_tests {
 
         mock_listener.wait_for_next_update().await.unwrap();
 
-        let received_update = mock_listener.force_get_most_recent_update();
+        let mut received_update = mock_listener.force_get_most_recent_update();
         assert_eq!(
-            received_update.data,
-            "reconnected_sync".to_string().into_bytes()
+            received_update.data.read_to_string().unwrap(),
+            "reconnected_sync".to_string()
         );
         assert_eq!(
             received_update.source,
